@@ -71,24 +71,39 @@ class Remote:
         self.list_plugins = {}
 
         cache = Path(self.folder / ".cache_qgis_plugin_manager")
+        if not cache.exists():
+            cache.mkdir()
+            print("The 'update' has not been done before.")
+            print("Running the update to download XML files first.")
+            self.update()
+
+        has_xml = False
         for file in cache.iterdir():
             if not file.name.endswith('.xml'):
                 continue
 
+            has_xml = True
+
             tree = ET.parse(file.absolute())
             root = tree.getroot()
             for plugin in root:
 
+                experimental = False
+                for element in plugin:
+                    if element.tag == 'experimental':
+                        experimental = element.text == "True"
+
                 xml_plugin_name = plugin.attrib['name']
                 if xml_plugin_name in plugins.keys():
                     previous_parsed_version = plugins[xml_plugin_name].split('.')
                     new_parsed_version = plugin.attrib['version'].split('.')
-                    if previous_parsed_version < new_parsed_version:
+                    if previous_parsed_version < new_parsed_version and not experimental:
                         plugins[xml_plugin_name] = plugin.attrib['version']
                     else:
                         continue
                 else:
-                    plugins[xml_plugin_name] = plugin.attrib['version']
+                    if not experimental:
+                        plugins[xml_plugin_name] = plugin.attrib['version']
 
                 plugin_obj = Plugin()
                 data = {}
@@ -99,6 +114,10 @@ class Remote:
                 plugin_obj = Plugin(**data)
                 self.list_plugins[xml_plugin_name] = plugin_obj
 
+        if not has_xml:
+            print("No remote repositories found !")
+            return None
+
         return plugins.get(plugin_name)
 
     def install(self, plugin_name, version="latest"):
